@@ -15,16 +15,12 @@ from yellowdog_client.common import SearchClient
 from yellowdog_client.model import (
     Allowance,
     AllowanceSearch,
-    Application,
-    ApplicationSearch,
     ComputeRequirement,
     ComputeRequirementSearch,
     ComputeRequirementStatus,
     ComputeRequirementTemplateSummary,
     ComputeSourceTemplateSummary,
     Group,
-    GroupSearch,
-    GroupSummary,
     Instance,
     InstanceSearch,
     Keyring,
@@ -39,12 +35,9 @@ from yellowdog_client.model import (
     NodeStatus,
     ObjectDetail,
     Role,
-    RoleSearch,
-    RoleSummary,
     Task,
     TaskGroup,
     User,
-    UserSearch,
     Worker,
     WorkerPoolStatus,
     WorkerPoolSummary,
@@ -54,9 +47,15 @@ from yellowdog_client.model import (
 )
 
 from yellowdog_cli.utils.entity_utils import (
+    get_all_applications,
+    get_all_groups,
+    get_all_roles,
+    get_all_users,
+    get_application_groups,
     get_filtered_work_requirements,
     get_task_groups_from_wr_summary,
     get_tasks,
+    get_user_groups,
     list_matching_object_paths,
     substitute_ids_for_names_in_crt,
 )
@@ -872,54 +871,57 @@ def list_users():
     """
     List all users in the account.
     """
-    user_search = UserSearch()
-    search_client: SearchClient = CLIENT.account_client.get_users(user_search)
-    users: List[User] = search_client.list_all()
-
-    users.sort(key=lambda user: user.name)
+    users: List[User] = get_all_users(CLIENT)
 
     if len(users) == 0:
         print_log("No Users to display")
         return
 
+    users.sort(key=lambda user: user.name)
+
     if not ARGS_PARSER.details:
         print_numbered_object_list(CLIENT, users, object_type_name="User")
         return
 
-    for selected_users in select(CLIENT, users, object_type_name="User"):
-        print_yd_object(selected_users)
+    for selected_user in select(CLIENT, users, object_type_name="User"):
+        add_groups_field = {
+            "groups": [
+                group.name for group in get_user_groups(CLIENT, selected_user.id)
+            ]
+        }
+        print_yd_object(selected_user, add_fields=add_groups_field)
 
 
 def list_applications():
     """
     List all applications in the account.
     """
-    application_search = ApplicationSearch()
-    search_client: SearchClient = CLIENT.account_client.get_applications(
-        application_search
-    )
-    applications: List[Application] = search_client.list_all()
-    applications.sort(key=lambda app: app.name)
+    applications = get_all_applications(CLIENT)
 
     if len(applications) == 0:
         print_log("No Applications to display")
         return
 
+    applications.sort(key=lambda app: app.name)
+
     if not ARGS_PARSER.details:
         print_numbered_object_list(CLIENT, applications, object_type_name="Application")
         return
 
-    for selected_users in select(CLIENT, applications, object_type_name="Application"):
-        print_yd_object(selected_users)
+    for selected_app in select(CLIENT, applications, object_type_name="Application"):
+        add_groups_field = {
+            "groups": [
+                group.name for group in get_application_groups(CLIENT, selected_app.id)
+            ]
+        }
+        print_yd_object(selected_app, add_fields=add_groups_field)
 
 
 def list_groups():
     """
     List all groups in the account.
     """
-    group_search = GroupSearch()
-    search_client: SearchClient = CLIENT.account_client.get_groups(group_search)
-    group_summaries: List[GroupSummary] = search_client.list_all()
+    group_summaries = get_all_groups(CLIENT)
 
     if len(group_summaries) == 0:
         print_log("No Groups to display")
@@ -943,9 +945,7 @@ def list_roles():
     """
     List all roles in the account.
     """
-    role_search = RoleSearch()
-    search_client: SearchClient = CLIENT.account_client.get_roles(role_search)
-    role_summaries: List[RoleSummary] = search_client.list_all()
+    role_summaries = get_all_roles(CLIENT)
 
     if len(role_summaries) == 0:
         print_log("No Roles to display")
