@@ -9,6 +9,8 @@ from yellowdog_client import PlatformClient
 from yellowdog_client.common import SearchClient
 from yellowdog_client.model import (
     AllowanceSearch,
+    Application,
+    ApplicationSearch,
     ComputeRequirement,
     ComputeRequirementSearch,
     ComputeRequirementStatus,
@@ -16,15 +18,23 @@ from yellowdog_client.model import (
     ComputeRequirementTemplateSummary,
     ComputeSourceTemplate,
     ComputeSourceTemplateSummary,
+    ExternalUser,
+    GroupSearch,
+    GroupSummary,
+    InternalUser,
     MachineImageFamily,
     MachineImageFamilySearch,
     MachineImageFamilySummary,
     ObjectPath,
     ObjectPathsRequest,
     ProvisionedWorkerPool,
+    RoleSearch,
+    RoleSummary,
     Task,
     TaskGroup,
     TaskSearch,
+    User,
+    UserSearch,
     WorkerPool,
     WorkerPoolSummary,
     WorkRequirementStatus,
@@ -554,3 +564,145 @@ def _get_image_family_name_from_id(
         return f"yd/{image_family.namespace}/{image_family.name}"
     except:
         return image_family_id
+
+
+@lru_cache
+def get_role_id_by_name(client: PlatformClient, role_name: str) -> Optional[str]:
+    """
+    Find the ID of a role by its name. Accept IDs and return unchanged.
+    """
+    if get_ydid_type(role_name) == YDIDType.ROLE:
+        return role_name
+
+    for role in get_all_roles(client):
+        if role_name == role.name:
+            return role.id
+
+    return None
+
+
+@lru_cache
+def get_role_name_by_id(client: PlatformClient, role_id: str) -> Optional[str]:
+    """
+    Get the name of a role by its ID.
+    """
+    for role in get_all_roles(client):
+        if role.id == role_id:
+            return role.name
+
+    return None
+
+
+@lru_cache
+def get_all_roles(client: PlatformClient) -> List[RoleSummary]:
+    """
+    Cache all roles.
+    """
+    role_search = RoleSearch()
+    search_client: SearchClient = client.account_client.get_roles(role_search)
+    return search_client.list_all()
+
+
+@lru_cache
+def get_group_id_by_name(client: PlatformClient, group_name: str) -> Optional[str]:
+    """
+    Get a group's ID by its name.
+    """
+    group_search = GroupSearch(name=group_name)
+    search_client: SearchClient = client.account_client.get_groups(group_search)
+    group_summaries: List[GroupSummary] = search_client.list_all()
+
+    for group_summary in group_summaries:
+        if group_summary.name == group_name:
+            return group_summary.id
+
+    return None
+
+
+@lru_cache
+def get_group_name_by_id(client: PlatformClient, group_id: str) -> Optional[str]:
+    """
+    Get a group's name by its ID.
+    """
+    for group in get_all_groups(client):
+        if group.id == group_id:
+            return group.name
+
+    return None
+
+
+@lru_cache
+def get_all_groups(client: PlatformClient) -> List[GroupSummary]:
+    """
+    Return a list of all the groups.
+    """
+    group_search = GroupSearch()
+    search_client: SearchClient = client.account_client.get_groups(group_search)
+    return search_client.list_all()
+
+
+@lru_cache
+def get_all_applications(client: PlatformClient) -> List[Application]:
+    """
+    Return a list of all the applications.
+    """
+    application_search = ApplicationSearch()
+    search_client: SearchClient = client.account_client.get_applications(
+        application_search
+    )
+    return search_client.list_all()
+
+
+@lru_cache
+def get_application_id_by_name(client: PlatformClient, app_name: str) -> Optional[str]:
+    """
+    Get an application ID by its name.
+    """
+    for app in get_all_applications(client):
+        if app.name == app_name:
+            return app.id
+
+    return None
+
+
+def get_application_groups(client: PlatformClient, app_id: str) -> List[GroupSummary]:
+    """
+    Get the groups to which an application belongs.
+    """
+    return client.account_client.get_application_groups(app_id).list_all()
+
+
+def get_user_groups(client: PlatformClient, user_id: str) -> List[GroupSummary]:
+    """
+    Get the groups to which a user belongs.
+    """
+    return client.account_client.get_user_groups(user_id).list_all()
+
+
+def get_user_by_name_or_id(
+    client: PlatformClient, user_name_or_id: str
+) -> Optional[User]:
+    """
+    Get a user ID by their username or ID.
+    """
+    for user in get_all_users(client):
+
+        if user.id == user_name_or_id:
+            return user
+
+        if (isinstance(user, InternalUser) and user.username == user_name_or_id) or (
+            isinstance(user, ExternalUser) and user.name == user_name_or_id
+        ):
+            return user
+
+    return None
+
+
+@lru_cache
+def get_all_users(client: PlatformClient) -> List[User]:
+    """
+    Return a list of all users.
+    """
+    user_search = UserSearch()
+    search_client: SearchClient = client.account_client.get_users(user_search)
+    return search_client.list_all()
